module.exports = function makeTilesApi(sizeup) {

  function overlay(opts, attribute) {

      attribute = attribute || {};
      opts = opts || {};
      var me = {};
      var urlSegment = attribute.url || '';
      me.params = sizeup.util.mergeParams(attribute.params || {}, opts);

      var getBaseUrl = function(){
          var urlBase = sizeup.loader.me.currentLocation + '/' + urlSegment;
          return urlBase;
      };
      var getTileUrl = function (point, zoom) {
          var baseUrl = getBaseUrl();
          var params = {
              x: point.x,
              y: point.y,
              zoom: zoom
          };
          params = sizeup.util.mergeParams(me.params, params);
          var url = sizeup.loader.buildTokenUrl(baseUrl, params);
          return url;
      };

      return { getTileUrl: getTileUrl };
  };

  // In this version, heatmap() only works for demographics, CEX, and
  // labor force metrics. It delegates to a deprecated interface.
  // The optional params "granularity", "boundingGeography", and
  // "industry" are all ignored.
  function heatmap(params) {

    var metric = params.metric;
    if ( ! metric) { throw new Error("Missing 'metric' parameter."); }

    var url = sizeup.loader.me.currentLocation + "/Areas/Tiles/DemographicsHeatmap.ashx";
    var szt = sizeup.loader.me.apiKey;
    var ds = "census";
    // TODO classify these prefixes somewhere else
    var bus_prefixes = ["BCC", "BUS", "EMP", "EST", "ESZ"];
    var cex_prefixes = ["TCY", "XCY"];
    if (bus_prefixes.indexOf(metric.substr(0,3)) != -1) { ds = "bus"; }
    if (cex_prefixes.indexOf(metric.substr(0,3)) != -1) { ds = "cex"; }

    if ( ! params.colors) { throw new Error("Missing 'colors' parameter."); }
    var c = params.colors.join(",");

    var getTileUrl = function(tileParams) {
      return sizeup.loader.buildTokenUrl(url, {
        SZT: szt,
        X: tileParams.x,
        Y: tileParams.y,
        Z: tileParams.zoom,
        C: c,
        DS: ds,
        DT: metric
      });
    }

    return { getTileUrl: getTileUrl };
  }

  return {
    overlay: overlay,
    heatmap: heatmap
  };
}
